VQA Guide
================================================

Variational quantum algos are promising class of introductory algorithms which can be (easily) implemented in orquestra.

.. toctree::
    :maxdepth: 2

    structure.rst
    ansatzes.rst
    estimators.rst